# restiro-spa-material

[![Build Status](https://travis-ci.org/meyt/restiro-spa-material.svg?branch=master)](https://travis-ci.org/meyt/restiro-spa-material)

Default [restiro](https://github.com/meyt/restiro) SPA template.

*Based on [Material Design](https://material.io) specs.*


## Usage

```
pip install restiro-spa-material
```

## Contribution

### Setup
```
npm install
```

### Development

```
npm run serve
```
